import { defineConfig } from "umi";

export default defineConfig({
  base: "/",
  publicPath: process.env.NODE_ENV === "production" ? "./" : "/",
  outputPath: "marketplace",
  esbuildMinifyIIFE: true,
  favicons: [],
  styles: ["//at.alicdn.com/t/c/font_4840729_yq3mj2py5j.css"],
  scripts: ["//at.alicdn.com/t/c/font_4840729_qpwqs1eruu.js"],
  model: {},
  metas: [
    {
      name: "viewport",
      content:
        "width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no",
    },
  ],
  history: {
    type: "hash",
  },
  plugins: [
    require.resolve('@umijs/plugins/dist/unocss'),
    require.resolve('@umijs/plugins/dist/model'),
    require.resolve('@umijs/plugins/dist/initial-state'),
    require.resolve('@umijs/plugins/dist/request'),
  ],
  // model: {},
  unocss: {
    watch: ["src/**/*.tsx"],
  },
  request: {
    dataField: '',
  },
  proxy: {
    "/api": {
      target: "https://design.shalu.com/",
      changeOrigin: true,
      pathRewrite: { "^/api": "" },
    },
  },
  routes: [
    {
      path: "/",
      redirect: "/application",
    },
    {
      path: "/application",
      component: "application",
    },
    {
      path: "/template",
      component: "template",
    },
    {
      // type: application or template
      path: "/detail/:type/:id",
      component: "detail",
    },
    {
      path: '/management',
      component: 'management',
      layout: false
    },
    {
      path: '/ai',
      component: 'ai',
      layout: false
    },
    {
      path: '/apply',
      component: 'apply',
      layout: false
    },
    {
      path: '*',
      component: '404',
      layout: false
    }
  ],
  npmClient: "pnpm",
});
