import React from "react";
import { Button } from "antd";
import { TagOutlined } from "@ant-design/icons";
export default function AppItem({
  data,
  onClick,
}: {
  data: any;
  onClick: (id: string) => void;
}) {
  return (
    <div className="relative overflow-hidden pb-2 group col-span-1 bg-white border-2 border-solid border-transparent rounded-lg shadow-sm flex flex-col transition-all duration-200 ease-in-out cursor-pointer hover:shadow-lg">
      <div className="flex pt-[14px] px-[14px] pb-3 h-[66px] items-center gap-3 grow-0 shrink-0">
        <div className="relative shrink-0">
          <span
            className="flex items-center justify-center relative rounded-lg grow-0 shrink-0 overflow-hidden w-10 h-10 text-[24px]"
            style={{ background: "rgb(224, 242, 254)" }}
          >
            <img className="w-full h-full" src={`/api/File/Download?fileId=${data?.icon}`}/>
          </span>
        </div>
        <div className="grow w-0 py-[1px]">
          <div className="flex items-center text-sm leading-5 font-semibold text-text-secondary">
            <div className="truncate" title="CRM客户关系管理系统">
              {data?.name}
            </div>
          </div>
          <div className="flex items-center text-[10px] leading-[18px] text-text-tertiary font-medium">
            <div className="truncate">作者 {data?.createByName || '易码工坊'}</div>
          </div>
        </div>
      </div>
      <div className="description-wrapper h-[90px] px-[14px] text-xs leading-normal text-text-tertiary ">
        <div className="line-clamp-4 group-hover:line-clamp-2">
          {data?.desc}
        </div>
      </div>
      <div>
        <div className="flex items-center h-5 px-[14px] text-12px">
          <div className="flex items-center space-x-1 text-text-tertiary">
            <svg
              viewBox="0 0 24 24"
              xmlns="http://www.w3.org/2000/svg"
              width="24"
              height="24"
              fill="currentColor"
              className="remixicon shrink-0 w-3 h-3"
            >
              <path d="M9 2V4H5L4.999 14H18.999L19 4H15V2H20C20.5523 2 21 2.44772 21 3V21C21 21.5523 20.5523 22 20 22H4C3.44772 22 3 21.5523 3 21V3C3 2.44772 3.44772 2 4 2H9ZM18.999 16H4.999L5 20H19L18.999 16ZM17 17V19H15V17H17ZM13 2V7H16L12 11L8 7H11V2H13Z"></path>
            </svg>
            <div className="system-xs-regular">339</div>
          </div>
          <div className="mx-2 text-text-quaternary system-xs-regular">·</div>
          <div className="flex flex-wrap space-x-2 h-4 overflow-hidden">
            {
              (data?.tags?.split(",") || []).map((tag: string, index: number) => {
                return <div
                key={index}
                className="flex space-x-1 system-xs-regular max-w-[120px] overflow-hidden"
                title={`# ${tag}`}
              >
                <span className="text-text-quaternary">#</span>
                <span className="truncate text-text-tertiary">{tag}</span>
              </div>
              })
            }
          </div>
        </div>
      </div>
      <div className="hidden items-center flex-wrap min-h-[42px] px-[14px] pt-2 pb-[10px] bg-white group-hover:flex absolute bottom-0 left-0 right-0">
        <div className="flex items-center w-full space-x-2">
          <Button
            type="primary"
            size="small"
            className="w-full"
            onClick={() => onClick(data.id)}
          >
            查看详情
          </Button>
        </div>
      </div>
    </div>
  );
}
